@@ -7,6 +7,7 @@ from progress.spinner import Spinner
 
 from .web.urls import TASK_STATUS_URL
 
+import threading
 
 class Task:
 
@@ -17,6 +18,9 @@ class Task:
         self.progress = 0
         self.task_state = "PENDING"
         self.callback = callback
+        if self.callback:
+            t = threading.Thread(target=self.callback_thread)
+            t.start()
         if show:
             self.update()
             print("Started {0}. View status at https://dashboard.neuro-ai.co.uk/tasks/{1}".format(self.task_type.lower(), task_id))
@@ -39,6 +43,10 @@ class Task:
         else:
             spinner.finish()
 
+    def callback_thread(self):
+        self.get_result()
+        self.callback(self.task_result)
+
     def get_result(self):
         self.wait()
         self.update(include_result=True)
