@@ -32,6 +32,8 @@ def predictApi(model, data_id, task_id):
     elif model != "" and not isinstance(model, Task):
         params["modelId"] = model
     response = requests.get(PREDICT_URL, params=params)
+    if response.status_code != 200:
+        raise ValueError(response.text)
     return response
 
 
